import { Utilities } from '@/util/Utilities';
import {
    Modal, ModalService, Text, Select, Form,
} from '@zeedhi/common';
import { Metadata } from '@zeedhi/core';

import { ZdDateRange, ZdTextInput } from '@zeedhi/vuetify';

import { TekGrid } from '@zeedhi/teknisa-components-common';

import Vue from 'vue';
import { ZdCalendar } from '@zeedhi/zd-calendar';

Vue.component('ZdCalendar', ZdCalendar);

export class CalendarioAgendamentoController {
    private LogModal!: Modal;

    private basicModal!: Modal;

    private FilterModal!: Modal;

    private ZerarModal!: Modal;

    private EditarModal!: Modal;

    public campoModal: any = {};

    public dadosFiltro: any = {};

    public currentRow: any = {};

    public mascaraSaldo: String = '';

    private visibilidadeGridCalendarioAgendamento: boolean = true;

    public get visibilidadeFrameCalendarioAgendamento() {
        return !this.visibilidadeGridCalendarioAgendamento;
    }

    public async abrirModalFilter() {
        await this.exibirModalFilter();
    }

    public async exibirModalDocumento() {
        this.basicModal = await ModalService.createFromJson('calendarioAgendamento/modal/calendarioAgendamentoFrame', true);
        this.basicModal.show();
    }

    public async exibirModalFilter() {
        this.FilterModal = await ModalService.createFromJson('calendarioAgendamento/modal/calendarioAgendamentoFiltro', true);
        this.FilterModal.show();
    }

    public fecharModalFilter() {
        this.FilterModal.hide();
        this.FilterModal?.destroy();
    }

    public fecharModalDocumento() {
        this.basicModal.hide();
        this.basicModal?.destroy();
    }

    public async abrirModalDocumento() {
        await this.exibirModalDocumento();
        Metadata.getInstance<Text>('titleText').text = 'Novo Anexo';
    }

    public async abrirModalEdicaoDocumento({ row }: any) {
        await this.exibirModalDocumento();
        Metadata.getInstance<Text>('titleText').text = 'Dados do agendamento';
        Metadata.getInstance<ZdTextInput>('DTAPROPRIACAO').value = row.DTAPROPRIACAO;
        Metadata.getInstance<ZdTextInput>('PERIODO').value = row.PERIODO;
        Metadata.getInstance<ZdTextInput>('AGENDAMENTO').value = row.AGENDAMENTO;
        Metadata.getInstance<ZdTextInput>('NMPRINCIPALPARC').value = row.NMPRINCIPALPARC;
        Metadata.getInstance<ZdTextInput>('DSATIVIDADESAGEND').value = row.DSATIVIDADESAGEND;
    }

    public fecharModalEditar() {
        this.EditarModal.hide();
        this.EditarModal?.destroy();
    }

    public eventFilter({ event }: any) {
        event.preventDefault();
        this.abrirModalFilterClick();
    }

    public async abrirModalFilterClick() {
        await this.exibirModalFilter();
        Metadata.getInstance<Select>('formFilterCalendarioAgendamento-CHAVE').value = this.campoModal.CHAVE;
        Metadata.getInstance<Select>('formFilterCalendarioAgendamento-CONTRATO').value = this.campoModal.NRSEQCONTRATO;
        Metadata.getInstance<Select>('formFilterCalendarioAgendamento-LOCAL').value = this.campoModal.NRESTRUTURAM;
        Metadata.getInstance<ZdDateRange>('formFilterCalendarioAgendamento-DTINIAGENDAMENTO').value = this.currentRow.DTINIAGENDAMENTO;
        Metadata.getInstance<ZdDateRange>('formFilterCalendarioAgendamento-DTFIMAGENDAMENTO').value = this.currentRow.DTFIMAGENDAMENTO;
    }

    public filterGrid() {
        const grid = Metadata.getInstance<TekGrid>('tekgrid-CalendarioAgendamento');
        const form = Metadata.getInstance<Form>('formFilterCalendarioAgendamento');
        
        this.dadosFiltro.CHAVE = Metadata.getInstance<Select>('formFilterCalendarioAgendamento-CHAVE').value;
        this.dadosFiltro.NRSEQCONTRATO = Metadata.getInstance<Select>('formFilterCalendarioAgendamento-CONTRATO').value;
        this.dadosFiltro.NRESTRUTURAM = Metadata.getInstance<Select>('formFilterCalendarioAgendamento-LOCAL').value;
        this.dadosFiltro.DTINIAGENDAMENTO = Metadata.getInstance<ZdDateRange>('formFilterCalendarioAgendamento-DTINIAGENDAMENTO').value;
        this.dadosFiltro.DTFIMAGENDAMENTO = Metadata.getInstance<ZdDateRange>('formFilterCalendarioAgendamento-DTFIMAGENDAMENTO').value;

        if (Utilities.validateForm(form)) {
            grid.datasource.setFilter({
                CHAVE: Metadata.getInstance<Select>('formFilterCalendarioAgendamento-CHAVE').value,
                NRSEQCONTRATO: Metadata.getInstance<Select>('formFilterCalendarioAgendamento-CONTRATO').value,
                NRESTRUTURAM: Metadata.getInstance<Select>('formFilterCalendarioAgendamento-LOCAL').value,
                DTINIAGENDAMENTO: Metadata.getInstance<ZdDateRange>('formFilterCalendarioAgendamento-DTINIAGENDAMENTO').value,
                DTFIMAGENDAMENTO: Metadata.getInstance<ZdDateRange>('formFilterCalendarioAgendamento-DTFIMAGENDAMENTO').value,
            });

            this.fecharModalFilter();
        }
    }
    
    public dayColor(date: string) {
        const day = Number(date.substring(date.length - 2));
        return day % 3 === 0 ? 'background-color: var(--v-primary-base);' : '';
    }
}
